.. py:currentmodule:: rubin_sim.satellite_constellations

.. _rubin_sim.satellite_constellations:

==================================
rubin_sim satellite constellations
==================================

Tools for creating and propigating satellite mega constellations and how they could streak Rubin images.


Python API
==========

* :ref:`rubin_sim.satellite_constellations api`

* :ref:`search`